# Generated by Django 3.2.6 on 2021-08-16 19:19

from django.db import migrations, models
import django.db.models.deletion
import djangocms_mdeditor.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='MarkdownText',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='mdeditor_markdowntext', serialize=False, to='cms.cmsplugin')),
                ('body', djangocms_mdeditor.models.MarkdownField(verbose_name='body')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
